.. _sample-configuration:

===========================
Glance Sample Configuration
===========================

The following are sample configuration files for all Glance services and
utilities. These are generated from code and reflect the current state of code
in the Glance repository.


Sample configuration for Glance API
-----------------------------------

This sample configuration can also be viewed in `glance-api.conf.sample
<../_static/glance-api.conf.sample>`_.

.. literalinclude:: ../_static/glance-api.conf.sample


Sample configuration for Glance Registry
----------------------------------------

This sample configuration can also be viewed in `glance-registry.conf.sample
<../_static/glance-registry.conf.sample>`_.

.. literalinclude:: ../_static/glance-registry.conf.sample


Sample configuration for Glance Scrubber
----------------------------------------

This sample configuration can also be viewed in `glance-scrubber.conf.sample
<../_static/glance-scrubber.conf.sample>`_.

.. literalinclude:: ../_static/glance-scrubber.conf.sample


Sample configuration for Glance Manage
--------------------------------------

This sample configuration can also be viewed in `glance-manage.conf.sample
<../_static/glance-manage.conf.sample>`_.

.. literalinclude:: ../_static/glance-manage.conf.sample


Sample configuration for Glance Cache
-------------------------------------

This sample configuration can also be viewed in `glance-cache.conf.sample
<../_static/glance-cache.conf.sample>`_.

.. literalinclude:: ../_static/glance-cache.conf.sample
